# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Iam Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.accountcommon_namespace_role import AccountcommonNamespaceRole
from ..models.accountcommon_permission import AccountcommonPermission
from ..models.model_user_active_ban_response import ModelUserActiveBanResponse


class ModelPublicUserResponse(Model):
    """Model public user response (model.PublicUserResponse)

    Properties:
        auth_type: (AuthType) REQUIRED str

        bans: (Bans) REQUIRED List[ModelUserActiveBanResponse]

        created_at: (CreatedAt) REQUIRED str

        deletion_status: (DeletionStatus) REQUIRED bool

        display_name: (DisplayName) REQUIRED str

        email_verified: (EmailVerified) REQUIRED bool

        enabled: (Enabled) REQUIRED bool

        last_enabled_changed_time: (LastEnabledChangedTime) REQUIRED str

        login_id: (LoginId) REQUIRED str

        namespace: (Namespace) REQUIRED str

        namespace_roles: (NamespaceRoles) REQUIRED List[AccountcommonNamespaceRole]

        permissions: (Permissions) REQUIRED List[AccountcommonPermission]

        phone_verified: (PhoneVerified) REQUIRED bool

        roles: (Roles) REQUIRED List[str]

        user_id: (UserId) REQUIRED str

        platform_id: (PlatformId) OPTIONAL str

        platform_user_id: (PlatformUserId) OPTIONAL str

        username: (Username) OPTIONAL str

        xuid: (XUID) OPTIONAL str
    """

    # region fields

    auth_type: str  # REQUIRED
    bans: List[ModelUserActiveBanResponse]  # REQUIRED
    created_at: str  # REQUIRED
    deletion_status: bool  # REQUIRED
    display_name: str  # REQUIRED
    email_verified: bool  # REQUIRED
    enabled: bool  # REQUIRED
    last_enabled_changed_time: str  # REQUIRED
    login_id: str  # REQUIRED
    namespace: str  # REQUIRED
    namespace_roles: List[AccountcommonNamespaceRole]  # REQUIRED
    permissions: List[AccountcommonPermission]  # REQUIRED
    phone_verified: bool  # REQUIRED
    roles: List[str]  # REQUIRED
    user_id: str  # REQUIRED
    platform_id: str  # OPTIONAL
    platform_user_id: str  # OPTIONAL
    username: str  # OPTIONAL
    xuid: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_auth_type(self, value: str) -> ModelPublicUserResponse:
        self.auth_type = value
        return self

    def with_bans(
        self, value: List[ModelUserActiveBanResponse]
    ) -> ModelPublicUserResponse:
        self.bans = value
        return self

    def with_created_at(self, value: str) -> ModelPublicUserResponse:
        self.created_at = value
        return self

    def with_deletion_status(self, value: bool) -> ModelPublicUserResponse:
        self.deletion_status = value
        return self

    def with_display_name(self, value: str) -> ModelPublicUserResponse:
        self.display_name = value
        return self

    def with_email_verified(self, value: bool) -> ModelPublicUserResponse:
        self.email_verified = value
        return self

    def with_enabled(self, value: bool) -> ModelPublicUserResponse:
        self.enabled = value
        return self

    def with_last_enabled_changed_time(self, value: str) -> ModelPublicUserResponse:
        self.last_enabled_changed_time = value
        return self

    def with_login_id(self, value: str) -> ModelPublicUserResponse:
        self.login_id = value
        return self

    def with_namespace(self, value: str) -> ModelPublicUserResponse:
        self.namespace = value
        return self

    def with_namespace_roles(
        self, value: List[AccountcommonNamespaceRole]
    ) -> ModelPublicUserResponse:
        self.namespace_roles = value
        return self

    def with_permissions(
        self, value: List[AccountcommonPermission]
    ) -> ModelPublicUserResponse:
        self.permissions = value
        return self

    def with_phone_verified(self, value: bool) -> ModelPublicUserResponse:
        self.phone_verified = value
        return self

    def with_roles(self, value: List[str]) -> ModelPublicUserResponse:
        self.roles = value
        return self

    def with_user_id(self, value: str) -> ModelPublicUserResponse:
        self.user_id = value
        return self

    def with_platform_id(self, value: str) -> ModelPublicUserResponse:
        self.platform_id = value
        return self

    def with_platform_user_id(self, value: str) -> ModelPublicUserResponse:
        self.platform_user_id = value
        return self

    def with_username(self, value: str) -> ModelPublicUserResponse:
        self.username = value
        return self

    def with_xuid(self, value: str) -> ModelPublicUserResponse:
        self.xuid = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "auth_type"):
            result["AuthType"] = str(self.auth_type)
        elif include_empty:
            result["AuthType"] = ""
        if hasattr(self, "bans"):
            result["Bans"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.bans
            ]
        elif include_empty:
            result["Bans"] = []
        if hasattr(self, "created_at"):
            result["CreatedAt"] = str(self.created_at)
        elif include_empty:
            result["CreatedAt"] = ""
        if hasattr(self, "deletion_status"):
            result["DeletionStatus"] = bool(self.deletion_status)
        elif include_empty:
            result["DeletionStatus"] = False
        if hasattr(self, "display_name"):
            result["DisplayName"] = str(self.display_name)
        elif include_empty:
            result["DisplayName"] = ""
        if hasattr(self, "email_verified"):
            result["EmailVerified"] = bool(self.email_verified)
        elif include_empty:
            result["EmailVerified"] = False
        if hasattr(self, "enabled"):
            result["Enabled"] = bool(self.enabled)
        elif include_empty:
            result["Enabled"] = False
        if hasattr(self, "last_enabled_changed_time"):
            result["LastEnabledChangedTime"] = str(self.last_enabled_changed_time)
        elif include_empty:
            result["LastEnabledChangedTime"] = ""
        if hasattr(self, "login_id"):
            result["LoginId"] = str(self.login_id)
        elif include_empty:
            result["LoginId"] = ""
        if hasattr(self, "namespace"):
            result["Namespace"] = str(self.namespace)
        elif include_empty:
            result["Namespace"] = ""
        if hasattr(self, "namespace_roles"):
            result["NamespaceRoles"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.namespace_roles
            ]
        elif include_empty:
            result["NamespaceRoles"] = []
        if hasattr(self, "permissions"):
            result["Permissions"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.permissions
            ]
        elif include_empty:
            result["Permissions"] = []
        if hasattr(self, "phone_verified"):
            result["PhoneVerified"] = bool(self.phone_verified)
        elif include_empty:
            result["PhoneVerified"] = False
        if hasattr(self, "roles"):
            result["Roles"] = [str(i0) for i0 in self.roles]
        elif include_empty:
            result["Roles"] = []
        if hasattr(self, "user_id"):
            result["UserId"] = str(self.user_id)
        elif include_empty:
            result["UserId"] = ""
        if hasattr(self, "platform_id"):
            result["PlatformId"] = str(self.platform_id)
        elif include_empty:
            result["PlatformId"] = ""
        if hasattr(self, "platform_user_id"):
            result["PlatformUserId"] = str(self.platform_user_id)
        elif include_empty:
            result["PlatformUserId"] = ""
        if hasattr(self, "username"):
            result["Username"] = str(self.username)
        elif include_empty:
            result["Username"] = ""
        if hasattr(self, "xuid"):
            result["XUID"] = str(self.xuid)
        elif include_empty:
            result["XUID"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        auth_type: str,
        bans: List[ModelUserActiveBanResponse],
        created_at: str,
        deletion_status: bool,
        display_name: str,
        email_verified: bool,
        enabled: bool,
        last_enabled_changed_time: str,
        login_id: str,
        namespace: str,
        namespace_roles: List[AccountcommonNamespaceRole],
        permissions: List[AccountcommonPermission],
        phone_verified: bool,
        roles: List[str],
        user_id: str,
        platform_id: Optional[str] = None,
        platform_user_id: Optional[str] = None,
        username: Optional[str] = None,
        xuid: Optional[str] = None,
        **kwargs,
    ) -> ModelPublicUserResponse:
        instance = cls()
        instance.auth_type = auth_type
        instance.bans = bans
        instance.created_at = created_at
        instance.deletion_status = deletion_status
        instance.display_name = display_name
        instance.email_verified = email_verified
        instance.enabled = enabled
        instance.last_enabled_changed_time = last_enabled_changed_time
        instance.login_id = login_id
        instance.namespace = namespace
        instance.namespace_roles = namespace_roles
        instance.permissions = permissions
        instance.phone_verified = phone_verified
        instance.roles = roles
        instance.user_id = user_id
        if platform_id is not None:
            instance.platform_id = platform_id
        if platform_user_id is not None:
            instance.platform_user_id = platform_user_id
        if username is not None:
            instance.username = username
        if xuid is not None:
            instance.xuid = xuid
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelPublicUserResponse:
        instance = cls()
        if not dict_:
            return instance
        if "AuthType" in dict_ and dict_["AuthType"] is not None:
            instance.auth_type = str(dict_["AuthType"])
        elif include_empty:
            instance.auth_type = ""
        if "Bans" in dict_ and dict_["Bans"] is not None:
            instance.bans = [
                ModelUserActiveBanResponse.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["Bans"]
            ]
        elif include_empty:
            instance.bans = []
        if "CreatedAt" in dict_ and dict_["CreatedAt"] is not None:
            instance.created_at = str(dict_["CreatedAt"])
        elif include_empty:
            instance.created_at = ""
        if "DeletionStatus" in dict_ and dict_["DeletionStatus"] is not None:
            instance.deletion_status = bool(dict_["DeletionStatus"])
        elif include_empty:
            instance.deletion_status = False
        if "DisplayName" in dict_ and dict_["DisplayName"] is not None:
            instance.display_name = str(dict_["DisplayName"])
        elif include_empty:
            instance.display_name = ""
        if "EmailVerified" in dict_ and dict_["EmailVerified"] is not None:
            instance.email_verified = bool(dict_["EmailVerified"])
        elif include_empty:
            instance.email_verified = False
        if "Enabled" in dict_ and dict_["Enabled"] is not None:
            instance.enabled = bool(dict_["Enabled"])
        elif include_empty:
            instance.enabled = False
        if (
            "LastEnabledChangedTime" in dict_
            and dict_["LastEnabledChangedTime"] is not None
        ):
            instance.last_enabled_changed_time = str(dict_["LastEnabledChangedTime"])
        elif include_empty:
            instance.last_enabled_changed_time = ""
        if "LoginId" in dict_ and dict_["LoginId"] is not None:
            instance.login_id = str(dict_["LoginId"])
        elif include_empty:
            instance.login_id = ""
        if "Namespace" in dict_ and dict_["Namespace"] is not None:
            instance.namespace = str(dict_["Namespace"])
        elif include_empty:
            instance.namespace = ""
        if "NamespaceRoles" in dict_ and dict_["NamespaceRoles"] is not None:
            instance.namespace_roles = [
                AccountcommonNamespaceRole.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["NamespaceRoles"]
            ]
        elif include_empty:
            instance.namespace_roles = []
        if "Permissions" in dict_ and dict_["Permissions"] is not None:
            instance.permissions = [
                AccountcommonPermission.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["Permissions"]
            ]
        elif include_empty:
            instance.permissions = []
        if "PhoneVerified" in dict_ and dict_["PhoneVerified"] is not None:
            instance.phone_verified = bool(dict_["PhoneVerified"])
        elif include_empty:
            instance.phone_verified = False
        if "Roles" in dict_ and dict_["Roles"] is not None:
            instance.roles = [str(i0) for i0 in dict_["Roles"]]
        elif include_empty:
            instance.roles = []
        if "UserId" in dict_ and dict_["UserId"] is not None:
            instance.user_id = str(dict_["UserId"])
        elif include_empty:
            instance.user_id = ""
        if "PlatformId" in dict_ and dict_["PlatformId"] is not None:
            instance.platform_id = str(dict_["PlatformId"])
        elif include_empty:
            instance.platform_id = ""
        if "PlatformUserId" in dict_ and dict_["PlatformUserId"] is not None:
            instance.platform_user_id = str(dict_["PlatformUserId"])
        elif include_empty:
            instance.platform_user_id = ""
        if "Username" in dict_ and dict_["Username"] is not None:
            instance.username = str(dict_["Username"])
        elif include_empty:
            instance.username = ""
        if "XUID" in dict_ and dict_["XUID"] is not None:
            instance.xuid = str(dict_["XUID"])
        elif include_empty:
            instance.xuid = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelPublicUserResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelPublicUserResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelPublicUserResponse,
        List[ModelPublicUserResponse],
        Dict[Any, ModelPublicUserResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "AuthType": "auth_type",
            "Bans": "bans",
            "CreatedAt": "created_at",
            "DeletionStatus": "deletion_status",
            "DisplayName": "display_name",
            "EmailVerified": "email_verified",
            "Enabled": "enabled",
            "LastEnabledChangedTime": "last_enabled_changed_time",
            "LoginId": "login_id",
            "Namespace": "namespace",
            "NamespaceRoles": "namespace_roles",
            "Permissions": "permissions",
            "PhoneVerified": "phone_verified",
            "Roles": "roles",
            "UserId": "user_id",
            "PlatformId": "platform_id",
            "PlatformUserId": "platform_user_id",
            "Username": "username",
            "XUID": "xuid",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "AuthType": True,
            "Bans": True,
            "CreatedAt": True,
            "DeletionStatus": True,
            "DisplayName": True,
            "EmailVerified": True,
            "Enabled": True,
            "LastEnabledChangedTime": True,
            "LoginId": True,
            "Namespace": True,
            "NamespaceRoles": True,
            "Permissions": True,
            "PhoneVerified": True,
            "Roles": True,
            "UserId": True,
            "PlatformId": False,
            "PlatformUserId": False,
            "Username": False,
            "XUID": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# Fleet Commander

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ApiDSHistoryEvent(Model):
    """Api DS history event (api.DSHistoryEvent)

    Properties:
        created_at: (createdAt) REQUIRED str

        exit_code: (exitCode) REQUIRED int

        ip_address: (ipAddress) REQUIRED str

        reason: (reason) REQUIRED str

        region: (region) REQUIRED str

        server_id: (serverId) REQUIRED str

        session_id: (sessionId) REQUIRED str

        status: (status) REQUIRED str
    """

    # region fields

    created_at: str  # REQUIRED
    exit_code: int  # REQUIRED
    ip_address: str  # REQUIRED
    reason: str  # REQUIRED
    region: str  # REQUIRED
    server_id: str  # REQUIRED
    session_id: str  # REQUIRED
    status: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_created_at(self, value: str) -> ApiDSHistoryEvent:
        self.created_at = value
        return self

    def with_exit_code(self, value: int) -> ApiDSHistoryEvent:
        self.exit_code = value
        return self

    def with_ip_address(self, value: str) -> ApiDSHistoryEvent:
        self.ip_address = value
        return self

    def with_reason(self, value: str) -> ApiDSHistoryEvent:
        self.reason = value
        return self

    def with_region(self, value: str) -> ApiDSHistoryEvent:
        self.region = value
        return self

    def with_server_id(self, value: str) -> ApiDSHistoryEvent:
        self.server_id = value
        return self

    def with_session_id(self, value: str) -> ApiDSHistoryEvent:
        self.session_id = value
        return self

    def with_status(self, value: str) -> ApiDSHistoryEvent:
        self.status = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "created_at"):
            result["createdAt"] = str(self.created_at)
        elif include_empty:
            result["createdAt"] = ""
        if hasattr(self, "exit_code"):
            result["exitCode"] = int(self.exit_code)
        elif include_empty:
            result["exitCode"] = 0
        if hasattr(self, "ip_address"):
            result["ipAddress"] = str(self.ip_address)
        elif include_empty:
            result["ipAddress"] = ""
        if hasattr(self, "reason"):
            result["reason"] = str(self.reason)
        elif include_empty:
            result["reason"] = ""
        if hasattr(self, "region"):
            result["region"] = str(self.region)
        elif include_empty:
            result["region"] = ""
        if hasattr(self, "server_id"):
            result["serverId"] = str(self.server_id)
        elif include_empty:
            result["serverId"] = ""
        if hasattr(self, "session_id"):
            result["sessionId"] = str(self.session_id)
        elif include_empty:
            result["sessionId"] = ""
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        created_at: str,
        exit_code: int,
        ip_address: str,
        reason: str,
        region: str,
        server_id: str,
        session_id: str,
        status: str,
        **kwargs,
    ) -> ApiDSHistoryEvent:
        instance = cls()
        instance.created_at = created_at
        instance.exit_code = exit_code
        instance.ip_address = ip_address
        instance.reason = reason
        instance.region = region
        instance.server_id = server_id
        instance.session_id = session_id
        instance.status = status
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApiDSHistoryEvent:
        instance = cls()
        if not dict_:
            return instance
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = str(dict_["createdAt"])
        elif include_empty:
            instance.created_at = ""
        if "exitCode" in dict_ and dict_["exitCode"] is not None:
            instance.exit_code = int(dict_["exitCode"])
        elif include_empty:
            instance.exit_code = 0
        if "ipAddress" in dict_ and dict_["ipAddress"] is not None:
            instance.ip_address = str(dict_["ipAddress"])
        elif include_empty:
            instance.ip_address = ""
        if "reason" in dict_ and dict_["reason"] is not None:
            instance.reason = str(dict_["reason"])
        elif include_empty:
            instance.reason = ""
        if "region" in dict_ and dict_["region"] is not None:
            instance.region = str(dict_["region"])
        elif include_empty:
            instance.region = ""
        if "serverId" in dict_ and dict_["serverId"] is not None:
            instance.server_id = str(dict_["serverId"])
        elif include_empty:
            instance.server_id = ""
        if "sessionId" in dict_ and dict_["sessionId"] is not None:
            instance.session_id = str(dict_["sessionId"])
        elif include_empty:
            instance.session_id = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiDSHistoryEvent]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiDSHistoryEvent]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApiDSHistoryEvent, List[ApiDSHistoryEvent], Dict[Any, ApiDSHistoryEvent]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "createdAt": "created_at",
            "exitCode": "exit_code",
            "ipAddress": "ip_address",
            "reason": "reason",
            "region": "region",
            "serverId": "server_id",
            "sessionId": "session_id",
            "status": "status",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "createdAt": True,
            "exitCode": True,
            "ipAddress": True,
            "reason": True,
            "region": True,
            "serverId": True,
            "sessionId": True,
            "status": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Session Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.models_psn_app_server_credentials import ModelsPSNAppServerCredentials
from ..models.models_xbl_certificate_credential import ModelsXBLCertificateCredential


class ModelsPlatformCredentials(Model):
    """Models platform credentials (models.PlatformCredentials)

    Properties:
        psn: (psn) REQUIRED ModelsPSNAppServerCredentials

        updated_at: (updatedAt) REQUIRED str

        xbox: (xbox) OPTIONAL ModelsXBLCertificateCredential
    """

    # region fields

    psn: ModelsPSNAppServerCredentials  # REQUIRED
    updated_at: str  # REQUIRED
    xbox: ModelsXBLCertificateCredential  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_psn(
        self, value: ModelsPSNAppServerCredentials
    ) -> ModelsPlatformCredentials:
        self.psn = value
        return self

    def with_updated_at(self, value: str) -> ModelsPlatformCredentials:
        self.updated_at = value
        return self

    def with_xbox(
        self, value: ModelsXBLCertificateCredential
    ) -> ModelsPlatformCredentials:
        self.xbox = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "psn"):
            result["psn"] = self.psn.to_dict(include_empty=include_empty)
        elif include_empty:
            result["psn"] = ModelsPSNAppServerCredentials()
        if hasattr(self, "updated_at"):
            result["updatedAt"] = str(self.updated_at)
        elif include_empty:
            result["updatedAt"] = ""
        if hasattr(self, "xbox"):
            result["xbox"] = self.xbox.to_dict(include_empty=include_empty)
        elif include_empty:
            result["xbox"] = ModelsXBLCertificateCredential()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        psn: ModelsPSNAppServerCredentials,
        updated_at: str,
        xbox: Optional[ModelsXBLCertificateCredential] = None,
        **kwargs,
    ) -> ModelsPlatformCredentials:
        instance = cls()
        instance.psn = psn
        instance.updated_at = updated_at
        if xbox is not None:
            instance.xbox = xbox
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsPlatformCredentials:
        instance = cls()
        if not dict_:
            return instance
        if "psn" in dict_ and dict_["psn"] is not None:
            instance.psn = ModelsPSNAppServerCredentials.create_from_dict(
                dict_["psn"], include_empty=include_empty
            )
        elif include_empty:
            instance.psn = ModelsPSNAppServerCredentials()
        if "updatedAt" in dict_ and dict_["updatedAt"] is not None:
            instance.updated_at = str(dict_["updatedAt"])
        elif include_empty:
            instance.updated_at = ""
        if "xbox" in dict_ and dict_["xbox"] is not None:
            instance.xbox = ModelsXBLCertificateCredential.create_from_dict(
                dict_["xbox"], include_empty=include_empty
            )
        elif include_empty:
            instance.xbox = ModelsXBLCertificateCredential()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsPlatformCredentials]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsPlatformCredentials]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsPlatformCredentials,
        List[ModelsPlatformCredentials],
        Dict[Any, ModelsPlatformCredentials],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "psn": "psn",
            "updatedAt": "updated_at",
            "xbox": "xbox",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "psn": True,
            "updatedAt": True,
            "xbox": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Platform Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class PlaystationIAPConfigRequest(Model):
    """Playstation IAP config request (PlaystationIAPConfigRequest)

    Properties:
        environment: (environment) REQUIRED str

        back_office_server_client_id: (backOfficeServerClientId) OPTIONAL str

        back_office_server_client_secret: (backOfficeServerClientSecret) OPTIONAL str

        enable_stream_job: (enableStreamJob) OPTIONAL bool

        stream_name: (streamName) OPTIONAL str

        stream_partner_name: (streamPartnerName) OPTIONAL str
    """

    # region fields

    environment: str  # REQUIRED
    back_office_server_client_id: str  # OPTIONAL
    back_office_server_client_secret: str  # OPTIONAL
    enable_stream_job: bool  # OPTIONAL
    stream_name: str  # OPTIONAL
    stream_partner_name: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_environment(self, value: str) -> PlaystationIAPConfigRequest:
        self.environment = value
        return self

    def with_back_office_server_client_id(
        self, value: str
    ) -> PlaystationIAPConfigRequest:
        self.back_office_server_client_id = value
        return self

    def with_back_office_server_client_secret(
        self, value: str
    ) -> PlaystationIAPConfigRequest:
        self.back_office_server_client_secret = value
        return self

    def with_enable_stream_job(self, value: bool) -> PlaystationIAPConfigRequest:
        self.enable_stream_job = value
        return self

    def with_stream_name(self, value: str) -> PlaystationIAPConfigRequest:
        self.stream_name = value
        return self

    def with_stream_partner_name(self, value: str) -> PlaystationIAPConfigRequest:
        self.stream_partner_name = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "environment"):
            result["environment"] = str(self.environment)
        elif include_empty:
            result["environment"] = ""
        if hasattr(self, "back_office_server_client_id"):
            result["backOfficeServerClientId"] = str(self.back_office_server_client_id)
        elif include_empty:
            result["backOfficeServerClientId"] = ""
        if hasattr(self, "back_office_server_client_secret"):
            result["backOfficeServerClientSecret"] = str(
                self.back_office_server_client_secret
            )
        elif include_empty:
            result["backOfficeServerClientSecret"] = ""
        if hasattr(self, "enable_stream_job"):
            result["enableStreamJob"] = bool(self.enable_stream_job)
        elif include_empty:
            result["enableStreamJob"] = False
        if hasattr(self, "stream_name"):
            result["streamName"] = str(self.stream_name)
        elif include_empty:
            result["streamName"] = ""
        if hasattr(self, "stream_partner_name"):
            result["streamPartnerName"] = str(self.stream_partner_name)
        elif include_empty:
            result["streamPartnerName"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        environment: str,
        back_office_server_client_id: Optional[str] = None,
        back_office_server_client_secret: Optional[str] = None,
        enable_stream_job: Optional[bool] = None,
        stream_name: Optional[str] = None,
        stream_partner_name: Optional[str] = None,
        **kwargs,
    ) -> PlaystationIAPConfigRequest:
        instance = cls()
        instance.environment = environment
        if back_office_server_client_id is not None:
            instance.back_office_server_client_id = back_office_server_client_id
        if back_office_server_client_secret is not None:
            instance.back_office_server_client_secret = back_office_server_client_secret
        if enable_stream_job is not None:
            instance.enable_stream_job = enable_stream_job
        if stream_name is not None:
            instance.stream_name = stream_name
        if stream_partner_name is not None:
            instance.stream_partner_name = stream_partner_name
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> PlaystationIAPConfigRequest:
        instance = cls()
        if not dict_:
            return instance
        if "environment" in dict_ and dict_["environment"] is not None:
            instance.environment = str(dict_["environment"])
        elif include_empty:
            instance.environment = ""
        if (
            "backOfficeServerClientId" in dict_
            and dict_["backOfficeServerClientId"] is not None
        ):
            instance.back_office_server_client_id = str(
                dict_["backOfficeServerClientId"]
            )
        elif include_empty:
            instance.back_office_server_client_id = ""
        if (
            "backOfficeServerClientSecret" in dict_
            and dict_["backOfficeServerClientSecret"] is not None
        ):
            instance.back_office_server_client_secret = str(
                dict_["backOfficeServerClientSecret"]
            )
        elif include_empty:
            instance.back_office_server_client_secret = ""
        if "enableStreamJob" in dict_ and dict_["enableStreamJob"] is not None:
            instance.enable_stream_job = bool(dict_["enableStreamJob"])
        elif include_empty:
            instance.enable_stream_job = False
        if "streamName" in dict_ and dict_["streamName"] is not None:
            instance.stream_name = str(dict_["streamName"])
        elif include_empty:
            instance.stream_name = ""
        if "streamPartnerName" in dict_ and dict_["streamPartnerName"] is not None:
            instance.stream_partner_name = str(dict_["streamPartnerName"])
        elif include_empty:
            instance.stream_partner_name = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, PlaystationIAPConfigRequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[PlaystationIAPConfigRequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        PlaystationIAPConfigRequest,
        List[PlaystationIAPConfigRequest],
        Dict[Any, PlaystationIAPConfigRequest],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "environment": "environment",
            "backOfficeServerClientId": "back_office_server_client_id",
            "backOfficeServerClientSecret": "back_office_server_client_secret",
            "enableStreamJob": "enable_stream_job",
            "streamName": "stream_name",
            "streamPartnerName": "stream_partner_name",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "environment": True,
            "backOfficeServerClientId": False,
            "backOfficeServerClientSecret": False,
            "enableStreamJob": False,
            "streamName": False,
            "streamPartnerName": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Cloudsave Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.models_ttl_config_dto import ModelsTTLConfigDTO


class ModelsAdminGameRecordResponse(Model):
    """Models admin game record response (models.AdminGameRecordResponse)

    Properties:
        created_at: (created_at) REQUIRED str

        key: (key) REQUIRED str

        namespace: (namespace) REQUIRED str

        updated_at: (updated_at) REQUIRED str

        value: (value) REQUIRED Dict[str, Any]

        tags: (tags) OPTIONAL List[str]

        ttl_config: (ttl_config) OPTIONAL ModelsTTLConfigDTO
    """

    # region fields

    created_at: str  # REQUIRED
    key: str  # REQUIRED
    namespace: str  # REQUIRED
    updated_at: str  # REQUIRED
    value: Dict[str, Any]  # REQUIRED
    tags: List[str]  # OPTIONAL
    ttl_config: ModelsTTLConfigDTO  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_created_at(self, value: str) -> ModelsAdminGameRecordResponse:
        self.created_at = value
        return self

    def with_key(self, value: str) -> ModelsAdminGameRecordResponse:
        self.key = value
        return self

    def with_namespace(self, value: str) -> ModelsAdminGameRecordResponse:
        self.namespace = value
        return self

    def with_updated_at(self, value: str) -> ModelsAdminGameRecordResponse:
        self.updated_at = value
        return self

    def with_value(self, value: Dict[str, Any]) -> ModelsAdminGameRecordResponse:
        self.value = value
        return self

    def with_tags(self, value: List[str]) -> ModelsAdminGameRecordResponse:
        self.tags = value
        return self

    def with_ttl_config(
        self, value: ModelsTTLConfigDTO
    ) -> ModelsAdminGameRecordResponse:
        self.ttl_config = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "created_at"):
            result["created_at"] = str(self.created_at)
        elif include_empty:
            result["created_at"] = ""
        if hasattr(self, "key"):
            result["key"] = str(self.key)
        elif include_empty:
            result["key"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "updated_at"):
            result["updated_at"] = str(self.updated_at)
        elif include_empty:
            result["updated_at"] = ""
        if hasattr(self, "value"):
            result["value"] = {str(k0): v0 for k0, v0 in self.value.items()}
        elif include_empty:
            result["value"] = {}
        if hasattr(self, "tags"):
            result["tags"] = [str(i0) for i0 in self.tags]
        elif include_empty:
            result["tags"] = []
        if hasattr(self, "ttl_config"):
            result["ttl_config"] = self.ttl_config.to_dict(include_empty=include_empty)
        elif include_empty:
            result["ttl_config"] = ModelsTTLConfigDTO()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        created_at: str,
        key: str,
        namespace: str,
        updated_at: str,
        value: Dict[str, Any],
        tags: Optional[List[str]] = None,
        ttl_config: Optional[ModelsTTLConfigDTO] = None,
        **kwargs,
    ) -> ModelsAdminGameRecordResponse:
        instance = cls()
        instance.created_at = created_at
        instance.key = key
        instance.namespace = namespace
        instance.updated_at = updated_at
        instance.value = value
        if tags is not None:
            instance.tags = tags
        if ttl_config is not None:
            instance.ttl_config = ttl_config
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsAdminGameRecordResponse:
        instance = cls()
        if not dict_:
            return instance
        if "created_at" in dict_ and dict_["created_at"] is not None:
            instance.created_at = str(dict_["created_at"])
        elif include_empty:
            instance.created_at = ""
        if "key" in dict_ and dict_["key"] is not None:
            instance.key = str(dict_["key"])
        elif include_empty:
            instance.key = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "updated_at" in dict_ and dict_["updated_at"] is not None:
            instance.updated_at = str(dict_["updated_at"])
        elif include_empty:
            instance.updated_at = ""
        if "value" in dict_ and dict_["value"] is not None:
            instance.value = {str(k0): v0 for k0, v0 in dict_["value"].items()}
        elif include_empty:
            instance.value = {}
        if "tags" in dict_ and dict_["tags"] is not None:
            instance.tags = [str(i0) for i0 in dict_["tags"]]
        elif include_empty:
            instance.tags = []
        if "ttl_config" in dict_ and dict_["ttl_config"] is not None:
            instance.ttl_config = ModelsTTLConfigDTO.create_from_dict(
                dict_["ttl_config"], include_empty=include_empty
            )
        elif include_empty:
            instance.ttl_config = ModelsTTLConfigDTO()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsAdminGameRecordResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsAdminGameRecordResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsAdminGameRecordResponse,
        List[ModelsAdminGameRecordResponse],
        Dict[Any, ModelsAdminGameRecordResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "created_at": "created_at",
            "key": "key",
            "namespace": "namespace",
            "updated_at": "updated_at",
            "value": "value",
            "tags": "tags",
            "ttl_config": "ttl_config",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "created_at": True,
            "key": True,
            "namespace": True,
            "updated_at": True,
            "value": True,
            "tags": False,
            "ttl_config": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Session History Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.models_party import ModelsParty


class ApimodelsPartyHistory(Model):
    """Apimodels party history (apimodels.PartyHistory)

    Properties:
        event_name: (eventName) REQUIRED str

        payload: (payload) REQUIRED ModelsParty

        timestamp: (timestamp) REQUIRED str

        requester_client_id: (requesterClientID) OPTIONAL str

        requester_user_id: (requesterUserID) OPTIONAL str
    """

    # region fields

    event_name: str  # REQUIRED
    payload: ModelsParty  # REQUIRED
    timestamp: str  # REQUIRED
    requester_client_id: str  # OPTIONAL
    requester_user_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_event_name(self, value: str) -> ApimodelsPartyHistory:
        self.event_name = value
        return self

    def with_payload(self, value: ModelsParty) -> ApimodelsPartyHistory:
        self.payload = value
        return self

    def with_timestamp(self, value: str) -> ApimodelsPartyHistory:
        self.timestamp = value
        return self

    def with_requester_client_id(self, value: str) -> ApimodelsPartyHistory:
        self.requester_client_id = value
        return self

    def with_requester_user_id(self, value: str) -> ApimodelsPartyHistory:
        self.requester_user_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "event_name"):
            result["eventName"] = str(self.event_name)
        elif include_empty:
            result["eventName"] = ""
        if hasattr(self, "payload"):
            result["payload"] = self.payload.to_dict(include_empty=include_empty)
        elif include_empty:
            result["payload"] = ModelsParty()
        if hasattr(self, "timestamp"):
            result["timestamp"] = str(self.timestamp)
        elif include_empty:
            result["timestamp"] = ""
        if hasattr(self, "requester_client_id"):
            result["requesterClientID"] = str(self.requester_client_id)
        elif include_empty:
            result["requesterClientID"] = ""
        if hasattr(self, "requester_user_id"):
            result["requesterUserID"] = str(self.requester_user_id)
        elif include_empty:
            result["requesterUserID"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        event_name: str,
        payload: ModelsParty,
        timestamp: str,
        requester_client_id: Optional[str] = None,
        requester_user_id: Optional[str] = None,
        **kwargs,
    ) -> ApimodelsPartyHistory:
        instance = cls()
        instance.event_name = event_name
        instance.payload = payload
        instance.timestamp = timestamp
        if requester_client_id is not None:
            instance.requester_client_id = requester_client_id
        if requester_user_id is not None:
            instance.requester_user_id = requester_user_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsPartyHistory:
        instance = cls()
        if not dict_:
            return instance
        if "eventName" in dict_ and dict_["eventName"] is not None:
            instance.event_name = str(dict_["eventName"])
        elif include_empty:
            instance.event_name = ""
        if "payload" in dict_ and dict_["payload"] is not None:
            instance.payload = ModelsParty.create_from_dict(
                dict_["payload"], include_empty=include_empty
            )
        elif include_empty:
            instance.payload = ModelsParty()
        if "timestamp" in dict_ and dict_["timestamp"] is not None:
            instance.timestamp = str(dict_["timestamp"])
        elif include_empty:
            instance.timestamp = ""
        if "requesterClientID" in dict_ and dict_["requesterClientID"] is not None:
            instance.requester_client_id = str(dict_["requesterClientID"])
        elif include_empty:
            instance.requester_client_id = ""
        if "requesterUserID" in dict_ and dict_["requesterUserID"] is not None:
            instance.requester_user_id = str(dict_["requesterUserID"])
        elif include_empty:
            instance.requester_user_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsPartyHistory]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsPartyHistory]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsPartyHistory,
        List[ApimodelsPartyHistory],
        Dict[Any, ApimodelsPartyHistory],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "eventName": "event_name",
            "payload": "payload",
            "timestamp": "timestamp",
            "requesterClientID": "requester_client_id",
            "requesterUserID": "requester_user_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "eventName": True,
            "payload": True,
            "timestamp": True,
            "requesterClientID": False,
            "requesterUserID": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Lobby Server

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.lobby.models import HandlersGetUsersPresenceResponse
from ..api.lobby.models import HandlersUserPresence
from ..api.lobby.models import LogAppMessageDeclaration
from ..api.lobby.models import LogconfigConfiguration
from ..api.lobby.models import ModelBulkFriendsRequest
from ..api.lobby.models import ModelBulkFriendsResponse
from ..api.lobby.models import ModelBulkUsersFreeFormNotificationRequestV1
from ..api.lobby.models import ModelCreateTemplateRequest
from ..api.lobby.models import ModelCreateTopicRequest
from ..api.lobby.models import ModelCreateTopicRequestV1
from ..api.lobby.models import ModelFreeFormNotificationRequest
from ..api.lobby.models import ModelFreeFormNotificationRequestV1
from ..api.lobby.models import ModelFriendWithPlatform
from ..api.lobby.models import ModelFriendshipConnection
from ..api.lobby.models import ModelFriendshipConnectionResponse
from ..api.lobby.models import ModelGetAllNotificationTemplateSlugResp
from ..api.lobby.models import ModelGetAllNotificationTopicsResponse
from ..api.lobby.models import ModelGetFriendsResponse
from ..api.lobby.models import ModelGetUserFriendsResponse
from ..api.lobby.models import ModelGetUserIncomingFriendsResponse
from ..api.lobby.models import ModelGetUserOutgoingFriendsResponse
from ..api.lobby.models import ModelGlobalConfiguration
from ..api.lobby.models import ModelIncomingFriendsWithTimeData
from ..api.lobby.models import ModelListBulkUserPlatformsResponse
from ..api.lobby.models import ModelLoadIncomingFriendsWithTimeResponse
from ..api.lobby.models import ModelLoadOutgoingFriendsWithTimeResponse
from ..api.lobby.models import ModelLocalization
from ..api.lobby.models import ModelNativeFriendRequest
from ..api.lobby.models import ModelNativeFriendSyncResponse
from ..api.lobby.models import ModelNativeUserBlockRequest
from ..api.lobby.models import ModelNativeUserBlockResponse
from ..api.lobby.models import ModelNotificationResponse
from ..api.lobby.models import ModelNotificationTemplateResponse
from ..api.lobby.models import ModelNotificationTopicResponse
from ..api.lobby.models import ModelNotificationTopicResponseV1
from ..api.lobby.models import ModelNotificationWithTemplateRequest
from ..api.lobby.models import ModelNotificationWithTemplateRequestV1
from ..api.lobby.models import ModelOutgoingFriendsWithTimeData
from ..api.lobby.models import ModelPagination
from ..api.lobby.models import ModelPutGlobalConfigurationRequest
from ..api.lobby.models import ModelRequestUserPresence
from ..api.lobby.models import ModelTemplateContent
from ..api.lobby.models import ModelTemplateLocalization
from ..api.lobby.models import ModelTemplateLocalizationResponse
from ..api.lobby.models import ModelTemplateResponse
from ..api.lobby.models import ModelTopicByNamespacesResponse
from ..api.lobby.models import ModelUpdateTemplateRequest
from ..api.lobby.models import ModelUpdateTopicRequest
from ..api.lobby.models import ModelUserAcceptFriendRequest
from ..api.lobby.models import ModelUserCancelFriendRequest
from ..api.lobby.models import ModelUserGetFriendshipStatusResponse
from ..api.lobby.models import ModelUserPlatformInfo
from ..api.lobby.models import ModelUserRejectFriendRequest
from ..api.lobby.models import ModelUserRequestFriendRequest
from ..api.lobby.models import ModelUserUnfriendRequest
from ..api.lobby.models import ModelUserWithPlatformInfo
from ..api.lobby.models import ModelsAdminAddProfanityFilterIntoListRequest
from ..api.lobby.models import ModelsAdminAddProfanityFiltersFilterRequest
from ..api.lobby.models import ModelsAdminAddProfanityFiltersRequest
from ..api.lobby.models import ModelsAdminCreateProfanityListRequest
from ..api.lobby.models import ModelsAdminDeleteProfanityFilterRequest
from ..api.lobby.models import ModelsAdminGetProfanityListFiltersV1Response
from ..api.lobby.models import ModelsAdminGetProfanityListsListResponse
from ..api.lobby.models import ModelsAdminSetProfanityRuleForNamespaceRequest
from ..api.lobby.models import ModelsAdminUpdateProfanityList
from ..api.lobby.models import ModelsAdminVerifyMessageProfanityRequest
from ..api.lobby.models import ModelsAdminVerifyMessageProfanityResponse
from ..api.lobby.models import ModelsBlockPlayerRequest
from ..api.lobby.models import ModelsBlockedByPlayerData
from ..api.lobby.models import ModelsBlockedPlayerData
from ..api.lobby.models import ModelsConfig
from ..api.lobby.models import ModelsConfigList
from ..api.lobby.models import ModelsConfigReq
from ..api.lobby.models import ModelsCreateConfigRequest
from ..api.lobby.models import ModelsCreateConfigResponse
from ..api.lobby.models import ModelsDebugProfanityFilterRequest
from ..api.lobby.models import ModelsGetAllPlayerBlockedByUsersResponse
from ..api.lobby.models import ModelsGetAllPlayerBlockedUsersResponse
from ..api.lobby.models import ModelsGetAllPlayerSessionAttributeResponse
from ..api.lobby.models import ModelsGetBulkAllPlayerBlockedUsersRequest
from ..api.lobby.models import ModelsGetBulkAllPlayerBlockedUsersResponse
from ..api.lobby.models import ModelsGetConfigResponse
from ..api.lobby.models import ModelsGetLobbyCcuResponse
from ..api.lobby.models import ModelsGetPlayerSessionAttributeResponse
from ..api.lobby.models import ModelsImportConfigResponse
from ..api.lobby.models import ModelsListBlockedPlayerRequest
from ..api.lobby.models import ModelsListUnblockPlayerRequest
from ..api.lobby.models import ModelsPartyData
from ..api.lobby.models import ModelsPartyPUTCustomAttributesRequest
from ..api.lobby.models import ModelsPartyPUTLimitSizeRequest
from ..api.lobby.models import ModelsProfanityFilter
from ..api.lobby.models import ModelsProfanityRule
from ..api.lobby.models import ModelsSetPlayerSessionAttributeRequest
from ..api.lobby.models import ModelsUnblockPlayerRequest
from ..api.lobby.models import ModelsUpdateConfigRequest
from ..api.lobby.models import ModelsUpdateConfigResponse
from ..api.lobby.models import ResponseError
from ..api.lobby.models import RestapiErrorResponseBody
from ..api.lobby.models import RestapiErrorResponseV1


def create_handlers_get_users_presence_response_example() -> (
    HandlersGetUsersPresenceResponse
):
    instance = HandlersGetUsersPresenceResponse()
    instance.away = randomize("int", min_val=1, max_val=1000)
    instance.busy = randomize("int", min_val=1, max_val=1000)
    instance.data = [create_handlers_user_presence_example()]
    instance.invisible = randomize("int", min_val=1, max_val=1000)
    instance.offline = randomize("int", min_val=1, max_val=1000)
    instance.online = randomize("int", min_val=1, max_val=1000)
    return instance


def create_handlers_user_presence_example() -> HandlersUserPresence:
    instance = HandlersUserPresence()
    instance.activity = randomize()
    instance.availability = randomize()
    instance.last_seen_at = randomize()
    instance.namespace = randomize("slug")
    instance.platform = randomize()
    instance.user_id = randomize("uid")
    return instance


def create_log_app_message_declaration_example() -> LogAppMessageDeclaration:
    instance = LogAppMessageDeclaration()
    instance.attributes = [randomize()]
    instance.code = randomize()
    instance.code_name = randomize()
    instance.section = randomize()
    instance.service = randomize()
    instance.text = randomize()
    return instance


def create_logconfig_configuration_example() -> LogconfigConfiguration:
    instance = LogconfigConfiguration()
    instance.log_level = randomize()
    instance.log_level_db = randomize()
    instance.slow_query_threshold = randomize("int", min_val=1, max_val=1000)
    instance.socket_log_enabled = randomize("bool")
    return instance


def create_model_bulk_friends_request_example() -> ModelBulkFriendsRequest:
    instance = ModelBulkFriendsRequest()
    instance.friend_ids = [randomize()]
    return instance


def create_model_bulk_friends_response_example() -> ModelBulkFriendsResponse:
    instance = ModelBulkFriendsResponse()
    instance.rows_affected = randomize("int", min_val=1, max_val=1000)
    return instance


def create_model_bulk_users_free_form_notification_request_v1_example() -> (
    ModelBulkUsersFreeFormNotificationRequestV1
):
    instance = ModelBulkUsersFreeFormNotificationRequestV1()
    instance.message = randomize()
    instance.topic_name = randomize()
    instance.user_ids = [randomize()]
    return instance


def create_model_create_template_request_example() -> ModelCreateTemplateRequest:
    instance = ModelCreateTemplateRequest()
    instance.template_content = randomize()
    instance.template_language = randomize()
    instance.template_slug = randomize()
    return instance


def create_model_create_topic_request_example() -> ModelCreateTopicRequest:
    instance = ModelCreateTopicRequest()
    instance.description = randomize()
    instance.topic = randomize()
    return instance


def create_model_create_topic_request_v1_example() -> ModelCreateTopicRequestV1:
    instance = ModelCreateTopicRequestV1()
    instance.description = randomize()
    instance.topic_name = randomize()
    return instance


def create_model_free_form_notification_request_example() -> (
    ModelFreeFormNotificationRequest
):
    instance = ModelFreeFormNotificationRequest()
    instance.message = randomize()
    instance.topic = randomize()
    return instance


def create_model_free_form_notification_request_v1_example() -> (
    ModelFreeFormNotificationRequestV1
):
    instance = ModelFreeFormNotificationRequestV1()
    instance.message = randomize()
    instance.topic_name = randomize()
    return instance


def create_model_friend_with_platform_example() -> ModelFriendWithPlatform:
    instance = ModelFriendWithPlatform()
    instance.platform_id = randomize()
    instance.user_id = randomize("uid")
    return instance


def create_model_friendship_connection_example() -> ModelFriendshipConnection:
    instance = ModelFriendshipConnection()
    instance.friend_id = randomize()
    instance.subject_id = randomize()
    return instance


def create_model_friendship_connection_response_example() -> (
    ModelFriendshipConnectionResponse
):
    instance = ModelFriendshipConnectionResponse()
    instance.data = [create_model_friendship_connection_example()]
    instance.paging = create_model_pagination_example()
    return instance


def create_model_get_all_notification_template_slug_resp_example() -> (
    ModelGetAllNotificationTemplateSlugResp
):
    instance = ModelGetAllNotificationTemplateSlugResp()
    instance.data = [create_model_localization_example()]
    instance.paging = create_model_pagination_example()
    return instance


def create_model_get_all_notification_topics_response_example() -> (
    ModelGetAllNotificationTopicsResponse
):
    instance = ModelGetAllNotificationTopicsResponse()
    instance.data = [create_model_notification_topic_response_v1_example()]
    instance.paging = create_model_pagination_example()
    return instance


def create_model_get_friends_response_example() -> ModelGetFriendsResponse:
    instance = ModelGetFriendsResponse()
    instance.friend_i_ds = [randomize()]
    instance.friends_since_times = [randomize("date")]
    instance.paging = create_model_pagination_example()
    instance.friends = [create_model_friend_with_platform_example()]
    return instance


def create_model_get_user_friends_response_example() -> ModelGetUserFriendsResponse:
    instance = ModelGetUserFriendsResponse()
    instance.friend_i_ds = [randomize()]
    instance.paging = create_model_pagination_example()
    instance.friends = [create_model_friend_with_platform_example()]
    return instance


def create_model_get_user_incoming_friends_response_example() -> (
    ModelGetUserIncomingFriendsResponse
):
    instance = ModelGetUserIncomingFriendsResponse()
    instance.friend_i_ds = [randomize()]
    instance.paging = create_model_pagination_example()
    return instance


def create_model_get_user_outgoing_friends_response_example() -> (
    ModelGetUserOutgoingFriendsResponse
):
    instance = ModelGetUserOutgoingFriendsResponse()
    instance.friend_i_ds = [randomize()]
    instance.paging = create_model_pagination_example()
    return instance


def create_model_global_configuration_example() -> ModelGlobalConfiguration:
    instance = ModelGlobalConfiguration()
    instance.region_retry_mapping = {}
    instance.region_url_mapping = [randomize()]
    instance.test_game_mode = randomize()
    instance.test_region_url_mapping = [randomize()]
    instance.test_target_user_i_ds = [randomize()]
    instance.updated_at = randomize()
    return instance


def create_model_incoming_friends_with_time_data_example() -> (
    ModelIncomingFriendsWithTimeData
):
    instance = ModelIncomingFriendsWithTimeData()
    instance.friend_id = randomize()
    instance.requested_at = randomize("date")
    return instance


def create_model_list_bulk_user_platforms_response_example() -> (
    ModelListBulkUserPlatformsResponse
):
    instance = ModelListBulkUserPlatformsResponse()
    instance.data = [create_model_user_with_platform_info_example()]
    return instance


def create_model_load_incoming_friends_with_time_response_example() -> (
    ModelLoadIncomingFriendsWithTimeResponse
):
    instance = ModelLoadIncomingFriendsWithTimeResponse()
    instance.data = [create_model_incoming_friends_with_time_data_example()]
    instance.paging = create_model_pagination_example()
    return instance


def create_model_load_outgoing_friends_with_time_response_example() -> (
    ModelLoadOutgoingFriendsWithTimeResponse
):
    instance = ModelLoadOutgoingFriendsWithTimeResponse()
    instance.data = [create_model_outgoing_friends_with_time_data_example()]
    instance.paging = create_model_pagination_example()
    return instance


def create_model_localization_example() -> ModelLocalization:
    instance = ModelLocalization()
    instance.last_draft_at = randomize()
    instance.last_published_at = randomize()
    instance.template_content = create_model_template_content_example()
    instance.template_language = randomize()
    return instance


def create_model_native_friend_request_example() -> ModelNativeFriendRequest:
    instance = ModelNativeFriendRequest()
    instance.is_login = randomize("bool")
    instance.platform_id = randomize()
    instance.platform_token = randomize()
    instance.psn_env = randomize()
    return instance


def create_model_native_friend_sync_response_example() -> ModelNativeFriendSyncResponse:
    instance = ModelNativeFriendSyncResponse()
    instance.platform_id = randomize()
    instance.status = randomize()
    instance.detail = randomize()
    return instance


def create_model_native_user_block_request_example() -> ModelNativeUserBlockRequest:
    instance = ModelNativeUserBlockRequest()
    instance.platform_id = randomize()
    instance.psn_env = randomize()
    return instance


def create_model_native_user_block_response_example() -> ModelNativeUserBlockResponse:
    instance = ModelNativeUserBlockResponse()
    instance.platform_id = randomize()
    instance.status = randomize()
    instance.detail = randomize()
    return instance


def create_model_notification_response_example() -> ModelNotificationResponse:
    instance = ModelNotificationResponse()
    instance.sequence_id = randomize("int", min_val=1, max_val=1000)
    instance.sequence_number = randomize("int", min_val=1, max_val=1000)
    instance.type_ = randomize()
    instance.from_ = randomize()
    instance.id_ = randomize()
    instance.lobby_session_id = randomize()
    instance.login_type = randomize()
    instance.payload = randomize()
    instance.reconnect_from_code = randomize("int", min_val=1, max_val=1000)
    instance.sent_at = randomize()
    instance.to = randomize()
    instance.topic = randomize()
    return instance


def create_model_notification_template_response_example() -> (
    ModelNotificationTemplateResponse
):
    instance = ModelNotificationTemplateResponse()
    instance.template_localizations = [create_model_localization_example()]
    instance.template_slug = randomize()
    return instance


def create_model_notification_topic_response_example() -> (
    ModelNotificationTopicResponse
):
    instance = ModelNotificationTopicResponse()
    instance.created_at = randomize("int", min_val=1, max_val=1000)
    instance.description = randomize()
    instance.namespace = randomize("slug")
    instance.topic = randomize()
    return instance


def create_model_notification_topic_response_v1_example() -> (
    ModelNotificationTopicResponseV1
):
    instance = ModelNotificationTopicResponseV1()
    instance.created_at = randomize("int", min_val=1, max_val=1000)
    instance.description = randomize()
    instance.namespace = randomize("slug")
    instance.topic_name = randomize()
    return instance


def create_model_notification_with_template_request_example() -> (
    ModelNotificationWithTemplateRequest
):
    instance = ModelNotificationWithTemplateRequest()
    instance.template_context = {randomize(): randomize()}
    instance.template_language = randomize()
    instance.template_slug = randomize()
    instance.topic = randomize()
    return instance


def create_model_notification_with_template_request_v1_example() -> (
    ModelNotificationWithTemplateRequestV1
):
    instance = ModelNotificationWithTemplateRequestV1()
    instance.template_context = {randomize(): randomize()}
    instance.template_language = randomize()
    instance.template_slug = randomize()
    instance.topic_name = randomize()
    return instance


def create_model_outgoing_friends_with_time_data_example() -> (
    ModelOutgoingFriendsWithTimeData
):
    instance = ModelOutgoingFriendsWithTimeData()
    instance.friend_id = randomize()
    instance.requested_at = randomize("date")
    return instance


def create_model_pagination_example() -> ModelPagination:
    instance = ModelPagination()
    instance.first = randomize()
    instance.last = randomize()
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_model_put_global_configuration_request_example() -> (
    ModelPutGlobalConfigurationRequest
):
    instance = ModelPutGlobalConfigurationRequest()
    instance.region_retry_mapping = {}
    instance.region_url_mapping = [randomize()]
    instance.test_game_mode = randomize()
    instance.test_region_url_mapping = [randomize()]
    instance.test_target_user_i_ds = [randomize()]
    return instance


def create_model_request_user_presence_example() -> ModelRequestUserPresence:
    instance = ModelRequestUserPresence()
    instance.user_i_ds = [randomize()]
    return instance


def create_model_template_content_example() -> ModelTemplateContent:
    instance = ModelTemplateContent()
    instance.draft = randomize()
    instance.published = randomize()
    return instance


def create_model_template_localization_example() -> ModelTemplateLocalization:
    instance = ModelTemplateLocalization()
    instance.last_draft_at = randomize()
    instance.last_published_at = randomize()
    instance.template_content = create_model_template_content_example()
    instance.template_language = randomize()
    instance.template_slug = randomize()
    return instance


def create_model_template_localization_response_example() -> (
    ModelTemplateLocalizationResponse
):
    instance = ModelTemplateLocalizationResponse()
    instance.first = randomize()
    instance.last = randomize()
    instance.next_ = randomize()
    instance.previous = randomize()
    instance.template_localization = [create_model_template_localization_example()]
    return instance


def create_model_template_response_example() -> ModelTemplateResponse:
    instance = ModelTemplateResponse()
    instance.localizations = [create_model_localization_example()]
    instance.template_slug = randomize()
    return instance


def create_model_topic_by_namespaces_response_example() -> (
    ModelTopicByNamespacesResponse
):
    instance = ModelTopicByNamespacesResponse()
    instance.first = randomize()
    instance.last = randomize()
    instance.next_ = randomize()
    instance.previous = randomize()
    instance.topics = [create_model_notification_topic_response_example()]
    return instance


def create_model_update_template_request_example() -> ModelUpdateTemplateRequest:
    instance = ModelUpdateTemplateRequest()
    instance.template_content = randomize()
    return instance


def create_model_update_topic_request_example() -> ModelUpdateTopicRequest:
    instance = ModelUpdateTopicRequest()
    instance.description = randomize()
    return instance


def create_model_user_accept_friend_request_example() -> ModelUserAcceptFriendRequest:
    instance = ModelUserAcceptFriendRequest()
    instance.friend_id = randomize()
    return instance


def create_model_user_cancel_friend_request_example() -> ModelUserCancelFriendRequest:
    instance = ModelUserCancelFriendRequest()
    instance.friend_id = randomize()
    return instance


def create_model_user_get_friendship_status_response_example() -> (
    ModelUserGetFriendshipStatusResponse
):
    instance = ModelUserGetFriendshipStatusResponse()
    instance.code = randomize("int", min_val=1, max_val=1000)
    instance.name = randomize()
    return instance


def create_model_user_platform_info_example() -> ModelUserPlatformInfo:
    instance = ModelUserPlatformInfo()
    instance.platform_display_name = randomize()
    instance.platform_name = randomize()
    instance.platform_user_id = randomize()
    return instance


def create_model_user_reject_friend_request_example() -> ModelUserRejectFriendRequest:
    instance = ModelUserRejectFriendRequest()
    instance.friend_id = randomize()
    return instance


def create_model_user_request_friend_request_example() -> ModelUserRequestFriendRequest:
    instance = ModelUserRequestFriendRequest()
    instance.friend_id = randomize()
    instance.friend_public_id = randomize()
    instance.metadata = {randomize(): randomize()}
    return instance


def create_model_user_unfriend_request_example() -> ModelUserUnfriendRequest:
    instance = ModelUserUnfriendRequest()
    instance.friend_id = randomize()
    return instance


def create_model_user_with_platform_info_example() -> ModelUserWithPlatformInfo:
    instance = ModelUserWithPlatformInfo()
    instance.avatar_url = randomize("url")
    instance.display_name = randomize("slug")
    instance.platform_infos = [create_model_user_platform_info_example()]
    instance.user_id = randomize("uid")
    instance.username = randomize("slug")
    return instance


def create_models_admin_add_profanity_filter_into_list_request_example() -> (
    ModelsAdminAddProfanityFilterIntoListRequest
):
    instance = ModelsAdminAddProfanityFilterIntoListRequest()
    instance.filter_ = randomize()
    instance.note = randomize()
    return instance


def create_models_admin_add_profanity_filters_filter_request_example() -> (
    ModelsAdminAddProfanityFiltersFilterRequest
):
    instance = ModelsAdminAddProfanityFiltersFilterRequest()
    instance.filter_ = randomize()
    instance.note = randomize()
    return instance


def create_models_admin_add_profanity_filters_request_example() -> (
    ModelsAdminAddProfanityFiltersRequest
):
    instance = ModelsAdminAddProfanityFiltersRequest()
    instance.filters = [
        create_models_admin_add_profanity_filters_filter_request_example()
    ]
    return instance


def create_models_admin_create_profanity_list_request_example() -> (
    ModelsAdminCreateProfanityListRequest
):
    instance = ModelsAdminCreateProfanityListRequest()
    instance.is_enabled = randomize("bool")
    instance.is_mandatory = randomize("bool")
    instance.name = randomize()
    return instance


def create_models_admin_delete_profanity_filter_request_example() -> (
    ModelsAdminDeleteProfanityFilterRequest
):
    instance = ModelsAdminDeleteProfanityFilterRequest()
    instance.filter_ = randomize()
    return instance


def create_models_admin_get_profanity_list_filters_v1_response_example() -> (
    ModelsAdminGetProfanityListFiltersV1Response
):
    instance = ModelsAdminGetProfanityListFiltersV1Response()
    instance.filters = [create_models_profanity_filter_example()]
    return instance


def create_models_admin_get_profanity_lists_list_response_example() -> (
    ModelsAdminGetProfanityListsListResponse
):
    instance = ModelsAdminGetProfanityListsListResponse()
    instance.is_enabled = randomize("bool")
    instance.is_mandatory = randomize("bool")
    instance.name = randomize()
    return instance


def create_models_admin_set_profanity_rule_for_namespace_request_example() -> (
    ModelsAdminSetProfanityRuleForNamespaceRequest
):
    instance = ModelsAdminSetProfanityRuleForNamespaceRequest()
    instance.rule = randomize()
    return instance


def create_models_admin_update_profanity_list_example() -> (
    ModelsAdminUpdateProfanityList
):
    instance = ModelsAdminUpdateProfanityList()
    instance.is_enabled = randomize("bool")
    instance.is_mandatory = randomize("bool")
    instance.new_name = randomize()
    return instance


def create_models_admin_verify_message_profanity_request_example() -> (
    ModelsAdminVerifyMessageProfanityRequest
):
    instance = ModelsAdminVerifyMessageProfanityRequest()
    instance.message = randomize()
    instance.profanity_level = randomize()
    return instance


def create_models_admin_verify_message_profanity_response_example() -> (
    ModelsAdminVerifyMessageProfanityResponse
):
    instance = ModelsAdminVerifyMessageProfanityResponse()
    instance.filtered_message = randomize()
    instance.has_profanity = randomize("bool")
    return instance


def create_models_block_player_request_example() -> ModelsBlockPlayerRequest:
    instance = ModelsBlockPlayerRequest()
    instance.blocked_user_id = randomize()
    return instance


def create_models_blocked_by_player_data_example() -> ModelsBlockedByPlayerData:
    instance = ModelsBlockedByPlayerData()
    instance.blocked_at = randomize("date")
    instance.user_id = randomize("uid")
    return instance


def create_models_blocked_player_data_example() -> ModelsBlockedPlayerData:
    instance = ModelsBlockedPlayerData()
    instance.blocked_at = randomize("date")
    instance.blocked_user_id = randomize()
    return instance


def create_models_config_example() -> ModelsConfig:
    instance = ModelsConfig()
    instance.max_ds_wait_time = randomize("int", min_val=1, max_val=1000)
    instance.unregister_delay = randomize("int", min_val=1, max_val=1000)
    instance.allow_invite_non_connected_user = randomize("bool")
    instance.allow_join_party_during_matchmaking = randomize("bool")
    instance.auto_kick_on_disconnect = randomize("bool")
    instance.auto_kick_on_disconnect_delay = randomize("int", min_val=1, max_val=1000)
    instance.cancel_ticket_on_disconnect = randomize("bool")
    instance.chat_rate_limit_burst = randomize("int", min_val=1, max_val=1000)
    instance.chat_rate_limit_duration = randomize("int", min_val=1, max_val=1000)
    instance.concurrent_users_limit = randomize("int", min_val=1, max_val=1000)
    instance.disable_invitation_on_join_party = randomize("bool")
    instance.disable_remove_socket_old_connection = randomize("bool")
    instance.enable_chat = randomize("bool")
    instance.entitlement_check = randomize("bool")
    instance.entitlement_item_id = randomize()
    instance.general_rate_limit_burst = randomize("int", min_val=1, max_val=1000)
    instance.general_rate_limit_duration = randomize("int", min_val=1, max_val=1000)
    instance.keep_presence_activity_on_disconnect = randomize("bool")
    instance.max_friends_limit = randomize("int", min_val=1, max_val=1000)
    instance.max_party_member = randomize("int", min_val=1, max_val=1000)
    instance.namespace = randomize("slug")
    instance.profanity_filter = randomize("bool")
    instance.ready_consent_timeout = randomize("int", min_val=1, max_val=1000)
    instance.request_metadata_max_size = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_config_list_example() -> ModelsConfigList:
    instance = ModelsConfigList()
    instance.configs = [create_models_config_example()]
    return instance


def create_models_config_req_example() -> ModelsConfigReq:
    instance = ModelsConfigReq()
    instance.allow_invite_non_connected_user = randomize("bool")
    instance.allow_join_party_during_matchmaking = randomize("bool")
    instance.auto_kick_on_disconnect = randomize("bool")
    instance.auto_kick_on_disconnect_delay = randomize("int", min_val=1, max_val=1000)
    instance.cancel_ticket_on_disconnect = randomize("bool")
    instance.chat_rate_limit_burst = randomize("int", min_val=1, max_val=1000)
    instance.chat_rate_limit_duration = randomize("int", min_val=1, max_val=1000)
    instance.concurrent_users_limit = randomize("int", min_val=1, max_val=1000)
    instance.disable_invitation_on_join_party = randomize("bool")
    instance.enable_chat = randomize("bool")
    instance.entitlement_check = randomize("bool")
    instance.entitlement_item_id = randomize()
    instance.general_rate_limit_burst = randomize("int", min_val=1, max_val=1000)
    instance.general_rate_limit_duration = randomize("int", min_val=1, max_val=1000)
    instance.keep_presence_activity_on_disconnect = randomize("bool")
    instance.max_ds_wait_time = randomize("int", min_val=1, max_val=1000)
    instance.max_friends_limit = randomize("int", min_val=1, max_val=1000)
    instance.max_party_member = randomize("int", min_val=1, max_val=1000)
    instance.profanity_filter = randomize("bool")
    instance.ready_consent_timeout = randomize("int", min_val=1, max_val=1000)
    instance.request_metadata_max_size = randomize("int", min_val=1, max_val=1000)
    instance.unregister_delay = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_create_config_request_example() -> ModelsCreateConfigRequest:
    instance = ModelsCreateConfigRequest()
    instance.api_key = randomize()
    return instance


def create_models_create_config_response_example() -> ModelsCreateConfigResponse:
    instance = ModelsCreateConfigResponse()
    instance.api_key = randomize()
    instance.namespace = randomize("slug")
    return instance


def create_models_debug_profanity_filter_request_example() -> (
    ModelsDebugProfanityFilterRequest
):
    instance = ModelsDebugProfanityFilterRequest()
    instance.text = randomize()
    return instance


def create_models_get_all_player_blocked_by_users_response_example() -> (
    ModelsGetAllPlayerBlockedByUsersResponse
):
    instance = ModelsGetAllPlayerBlockedByUsersResponse()
    instance.data = [create_models_blocked_by_player_data_example()]
    return instance


def create_models_get_all_player_blocked_users_response_example() -> (
    ModelsGetAllPlayerBlockedUsersResponse
):
    instance = ModelsGetAllPlayerBlockedUsersResponse()
    instance.data = [create_models_blocked_player_data_example()]
    return instance


def create_models_get_all_player_session_attribute_response_example() -> (
    ModelsGetAllPlayerSessionAttributeResponse
):
    instance = ModelsGetAllPlayerSessionAttributeResponse()
    instance.attributes = {randomize(): randomize()}
    return instance


def create_models_get_bulk_all_player_blocked_users_request_example() -> (
    ModelsGetBulkAllPlayerBlockedUsersRequest
):
    instance = ModelsGetBulkAllPlayerBlockedUsersRequest()
    instance.list_blocked_user_id = [randomize()]
    return instance


def create_models_get_bulk_all_player_blocked_users_response_example() -> (
    ModelsGetBulkAllPlayerBlockedUsersResponse
):
    instance = ModelsGetBulkAllPlayerBlockedUsersResponse()
    instance.data = {}
    return instance


def create_models_get_config_response_example() -> ModelsGetConfigResponse:
    instance = ModelsGetConfigResponse()
    instance.api_key = randomize()
    instance.namespace = randomize("slug")
    return instance


def create_models_get_lobby_ccu_response_example() -> ModelsGetLobbyCcuResponse:
    instance = ModelsGetLobbyCcuResponse()
    instance.count_current_users = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_get_player_session_attribute_response_example() -> (
    ModelsGetPlayerSessionAttributeResponse
):
    instance = ModelsGetPlayerSessionAttributeResponse()
    instance.key = randomize()
    instance.value = randomize()
    return instance


def create_models_import_config_response_example() -> ModelsImportConfigResponse:
    instance = ModelsImportConfigResponse()
    instance.failed_configs = [randomize()]
    instance.ignored_configs = [randomize()]
    instance.new_configs = [randomize()]
    instance.replaced_configs = [randomize()]
    return instance


def create_models_list_blocked_player_request_example() -> (
    ModelsListBlockedPlayerRequest
):
    instance = ModelsListBlockedPlayerRequest()
    instance.list_blocked_user_id = [randomize()]
    return instance


def create_models_list_unblock_player_request_example() -> (
    ModelsListUnblockPlayerRequest
):
    instance = ModelsListUnblockPlayerRequest()
    instance.list_unblock_user_id = [randomize()]
    return instance


def create_models_party_data_example() -> ModelsPartyData:
    instance = ModelsPartyData()
    instance.custom_attribute = {randomize(): randomize()}
    instance.invitees = [randomize()]
    instance.leader = randomize()
    instance.members = [randomize()]
    instance.namespace = randomize("slug")
    instance.party_id = randomize("uid")
    instance.updated_at = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_party_put_custom_attributes_request_example() -> (
    ModelsPartyPUTCustomAttributesRequest
):
    instance = ModelsPartyPUTCustomAttributesRequest()
    instance.custom_attribute = {randomize(): randomize()}
    instance.updated_at = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_party_put_limit_size_request_example() -> (
    ModelsPartyPUTLimitSizeRequest
):
    instance = ModelsPartyPUTLimitSizeRequest()
    instance.limit = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_profanity_filter_example() -> ModelsProfanityFilter:
    instance = ModelsProfanityFilter()
    instance.filter_ = randomize()
    instance.list_name = randomize()
    instance.namespace = randomize("slug")
    instance.note = randomize()
    return instance


def create_models_profanity_rule_example() -> ModelsProfanityRule:
    instance = ModelsProfanityRule()
    instance.namespace = randomize("slug")
    instance.rule = randomize()
    return instance


def create_models_set_player_session_attribute_request_example() -> (
    ModelsSetPlayerSessionAttributeRequest
):
    instance = ModelsSetPlayerSessionAttributeRequest()
    instance.attributes = {randomize(): randomize()}
    return instance


def create_models_unblock_player_request_example() -> ModelsUnblockPlayerRequest:
    instance = ModelsUnblockPlayerRequest()
    instance.user_id = randomize("uid")
    return instance


def create_models_update_config_request_example() -> ModelsUpdateConfigRequest:
    instance = ModelsUpdateConfigRequest()
    instance.api_key = randomize()
    return instance


def create_models_update_config_response_example() -> ModelsUpdateConfigResponse:
    instance = ModelsUpdateConfigResponse()
    instance.api_key = randomize()
    instance.namespace = randomize("slug")
    return instance


def create_response_error_example() -> ResponseError:
    instance = ResponseError()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    return instance


def create_restapi_error_response_body_example() -> RestapiErrorResponseBody:
    instance = RestapiErrorResponseBody()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    return instance


def create_restapi_error_response_v1_example() -> RestapiErrorResponseV1:
    instance = RestapiErrorResponseV1()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    return instance



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Platform Service."""

__version__ = "6.0.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .delete_loot_box_plugin_config import DeleteLootBoxPluginConfig
from .delete_revocation_plugi_c2651d import DeleteRevocationPluginConfig
from .delete_section_plugin_config import DeleteSectionPluginConfig
from .delete_service_plugin_config import DeleteServicePluginConfig
from .get_loot_box_grpc_info import GetLootBoxGrpcInfo
from .get_loot_box_plugin_config import GetLootBoxPluginConfig
from .get_revocation_plugin_config import GetRevocationPluginConfig
from .get_section_plugin_config import GetSectionPluginConfig
from .get_service_plugin_config import GetServicePluginConfig
from .update_loot_box_plugin_config import UpdateLootBoxPluginConfig
from .update_revocation_plugi_c19001 import UpdateRevocationPluginConfig
from .update_section_plugin_config import UpdateSectionPluginConfig
from .update_service_plugin_config import UpdateServicePluginConfig
from .upload_revocation_plugi_6c586a import UploadRevocationPluginConfigCert
from .upload_section_plugin_c_780cdd import UploadSectionPluginConfigCert
from .uplod_loot_box_plugin_c_5c5812 import UplodLootBoxPluginConfigCert



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsContentLikeRequest
from ..models import ModelsContentLikeResponse
from ..models import ModelsPaginatedContentLikersResponse
from ..models import ResponseError

from ..operations.public_like_v2 import PublicListContentLikeV2
from ..operations.public_like_v2 import UpdateContentLikeStatusV2


@same_doc_as(PublicListContentLikeV2)
def public_list_content_like_v2(
    content_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    sort_by: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve list of user that like specified content. (PublicListContentLikeV2)

    This endpoint will only display the list of users who performed like from v2 endpoint.

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents/{contentId}/like

        method: GET

        tags: ["Public Like V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

    Responses:
        200: OK - ModelsPaginatedContentLikersResponse (Retrieve list of user liked content)

        400: Bad Request - ResponseError (771004: invalid paging parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (771006: unable to get list of content like: database error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicListContentLikeV2.create(
        content_id=content_id,
        limit=limit,
        offset=offset,
        sort_by=sort_by,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicListContentLikeV2)
async def public_list_content_like_v2_async(
    content_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    sort_by: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve list of user that like specified content. (PublicListContentLikeV2)

    This endpoint will only display the list of users who performed like from v2 endpoint.

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents/{contentId}/like

        method: GET

        tags: ["Public Like V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

    Responses:
        200: OK - ModelsPaginatedContentLikersResponse (Retrieve list of user liked content)

        400: Bad Request - ResponseError (771004: invalid paging parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (771006: unable to get list of content like: database error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicListContentLikeV2.create(
        content_id=content_id,
        limit=limit,
        offset=offset,
        sort_by=sort_by,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateContentLikeStatusV2)
def update_content_like_status_v2(
    body: ModelsContentLikeRequest,
    content_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update like/unlike status to a content (UpdateContentLikeStatusV2)

    This endpoint will update like/unlike state from a content

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents/{contentId}/like

        method: PUT

        tags: ["Public Like V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsContentLikeRequest in body

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsContentLikeResponse (Update like/unlike status to a content)

        400: Bad Request - ResponseError (771000: Malformed request/Content not found/Unable to update like status: content not found)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (770200: Content not found | 771001: unable to like content/Unable to update like status: database error | 771000: Malformed request/Content not found/Unable to update like status: content not found)

        429: Too Many Requests - ResponseError (771003: Unable to like content: too many request)

        500: Internal Server Error - ResponseError (771001: unable to like content/Unable to update like status: database error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateContentLikeStatusV2.create(
        body=body,
        content_id=content_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateContentLikeStatusV2)
async def update_content_like_status_v2_async(
    body: ModelsContentLikeRequest,
    content_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update like/unlike status to a content (UpdateContentLikeStatusV2)

    This endpoint will update like/unlike state from a content

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents/{contentId}/like

        method: PUT

        tags: ["Public Like V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsContentLikeRequest in body

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsContentLikeResponse (Update like/unlike status to a content)

        400: Bad Request - ResponseError (771000: Malformed request/Content not found/Unable to update like status: content not found)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (770200: Content not found | 771001: unable to like content/Unable to update like status: database error | 771000: Malformed request/Content not found/Unable to update like status: content not found)

        429: Too Many Requests - ResponseError (771003: Unable to like content: too many request)

        500: Internal Server Error - ResponseError (771001: unable to like content/Unable to update like status: database error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateContentLikeStatusV2.create(
        body=body,
        content_id=content_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Lobby Server

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from .....core import Operation
from .....core import HeaderStr
from .....core import HttpResponse

from ...models import ResponseError


class AdminExportConfigV1(Operation):
    """Export lobby config to a json file. (adminExportConfigV1)


        Export lobby configuration to a json file. The file can then be imported from the /import endpoint.

        JSON Schema of the exported file:
        {
        "required": [
        "namespace",
        "entitlementItemID",
        "chatRateLimitDuration",
        "unregisterDelay",
        "generalRateLimitDuration",
        "autoKickOnDisconnectDelay",
        "chatRateLimitBurst",
        "generalRateLimitBurst",
        "maxPartyMember",
        "autoKickOnDisconnect",
        "profanityFilter",
        "enableChat",
        "entitlementCheck",
        "cancelTicketOnDisconnect",
        "concurrentUsersLimit",
        "readyConsentTimeout",
        "disableInvitationOnJoinParty",
        "allowJoinPartyDuringMatchmaking",
        "allowInviteNonConnectedUser",
        "keepPresenceActivityOnDisconnect",
        "maxDSWaitTime",
        "maxFriendsLimit",
        "requestMetadataMaxSize"
        ],
        "properties": {
        "allowInviteNonConnectedUser": {
        "type": "boolean"
        },
        "allowJoinPartyDuringMatchmaking": {
        "type": "boolean"
        },
        "autoKickOnDisconnect": {
        "type": "boolean"
        },
        "autoKickOnDisconnectDelay": {
        "type": "integer",
        "format": "int64"
        },
        "cancelTicketOnDisconnect": {
        "type": "boolean"
        },
        "chatRateLimitBurst": {
        "type": "integer",
        "format": "int32"
        },
        "chatRateLimitDuration": {
        "type": "integer",
        "format": "int64"
        },
        "concurrentUsersLimit": {
        "type": "integer",
        "format": "int32"
        },
        "disableInvitationOnJoinParty": {
        "type": "boolean"
        },
        "enableChat": {
        "type": "boolean"
        },
        "entitlementCheck": {
        "type": "boolean"
        },
        "entitlementItemID": {
        "type": "string"
        },
        "generalRateLimitBurst": {
        "type": "integer",
        "format": "int32"
        },
        "generalRateLimitDuration": {
        "type": "integer",
        "format": "int64"
        },
        "keepPresenceActivityOnDisconnect": {
        "type": "boolean"
        },
        "maxDSWaitTime": {
        "type": "integer",
        "format": "int64"
        },
        "maxFriendsLimit": {
        "type": "integer",
        "format": "int32"
        },
        "maxPartyMember": {
        "type": "integer",
        "format": "int32"
        },
        "namespace": {
        "type": "string"
        },
        "profanityFilter": {
        "type": "boolean"
        },
        "readyConsentTimeout": {
        "type": "integer",
        "format": "int64"
        },
        "requestMetadataMaxSize": {
        "type": "integer",
        "format": "int32"
        },
        "unregisterDelay": {
        "type": "integer",
        "format": "int64"
        }
        }
        }

        Properties:
            url: /lobby/v1/admin/config/namespaces/{namespace}/export

            method: GET

            tags: ["config"]

            consumes: []

            produces: ["application/json"]

            securities: [BEARER_AUTH]

            namespace: (namespace) REQUIRED str in path

        Responses:
            200: OK - Any (OK
    JSON Schema of the exported file:
    {
     "required": [
      "namespace",
      "entitlementItemID",
      "chatRateLimitDuration",
      "unregisterDelay",
      "generalRateLimitDuration",
      "autoKickOnDisconnectDelay",
      "chatRateLimitBurst",
      "generalRateLimitBurst",
      "maxPartyMember",
      "autoKickOnDisconnect",
      "profanityFilter",
      "enableChat",
      "entitlementCheck",
      "cancelTicketOnDisconnect",
      "concurrentUsersLimit",
      "readyConsentTimeout",
      "disableInvitationOnJoinParty",
      "allowJoinPartyDuringMatchmaking",
      "allowInviteNonConnectedUser",
      "keepPresenceActivityOnDisconnect",
      "maxDSWaitTime",
      "maxFriendsLimit",
      "requestMetadataMaxSize"
     ],
     "properties": {
      "allowInviteNonConnectedUser": {
       "type": "boolean"
      },
      "allowJoinPartyDuringMatchmaking": {
       "type": "boolean"
      },
      "autoKickOnDisconnect": {
       "type": "boolean"
      },
      "autoKickOnDisconnectDelay": {
       "type": "integer",
       "format": "int64"
      },
      "cancelTicketOnDisconnect": {
       "type": "boolean"
      },
      "chatRateLimitBurst": {
       "type": "integer",
       "format": "int32"
      },
      "chatRateLimitDuration": {
       "type": "integer",
       "format": "int64"
      },
      "concurrentUsersLimit": {
       "type": "integer",
       "format": "int32"
      },
      "disableInvitationOnJoinParty": {
       "type": "boolean"
      },
      "enableChat": {
       "type": "boolean"
      },
      "entitlementCheck": {
       "type": "boolean"
      },
      "entitlementItemID": {
       "type": "string"
      },
      "generalRateLimitBurst": {
       "type": "integer",
       "format": "int32"
      },
      "generalRateLimitDuration": {
       "type": "integer",
       "format": "int64"
      },
      "keepPresenceActivityOnDisconnect": {
       "type": "boolean"
      },
      "maxDSWaitTime": {
       "type": "integer",
       "format": "int64"
      },
      "maxFriendsLimit": {
       "type": "integer",
       "format": "int32"
      },
      "maxPartyMember": {
       "type": "integer",
       "format": "int32"
      },
      "namespace": {
       "type": "string"
      },
      "profanityFilter": {
       "type": "boolean"
      },
      "readyConsentTimeout": {
       "type": "integer",
       "format": "int64"
      },
      "requestMetadataMaxSize": {
       "type": "integer",
       "format": "int32"
      },
      "unregisterDelay": {
       "type": "integer",
       "format": "int64"
      }
     }
    })

            401: Unauthorized - ResponseError (Unauthorized)

            403: Forbidden - ResponseError (Forbidden)

            500: Internal Server Error - ResponseError (Internal Server Error)
    """

    # region fields

    _url: str = "/lobby/v1/admin/config/namespaces/{namespace}/export"
    _method: str = "GET"
    _consumes: List[str] = []
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"]]
    _location_query: str = None

    namespace: str  # REQUIRED in [path]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "path": self.get_path_params(),
        }

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_namespace(self, value: str) -> AdminExportConfigV1:
        self.namespace = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[Union[None, Any], Union[None, HttpResponse, ResponseError]]:
        """Parse the given response.

                200: OK - Any (OK
        JSON Schema of the exported file:
        {
         "required": [
          "namespace",
          "entitlementItemID",
          "chatRateLimitDuration",
          "unregisterDelay",
          "generalRateLimitDuration",
          "autoKickOnDisconnectDelay",
          "chatRateLimitBurst",
          "generalRateLimitBurst",
          "maxPartyMember",
          "autoKickOnDisconnect",
          "profanityFilter",
          "enableChat",
          "entitlementCheck",
          "cancelTicketOnDisconnect",
          "concurrentUsersLimit",
          "readyConsentTimeout",
          "disableInvitationOnJoinParty",
          "allowJoinPartyDuringMatchmaking",
          "allowInviteNonConnectedUser",
          "keepPresenceActivityOnDisconnect",
          "maxDSWaitTime",
          "maxFriendsLimit",
          "requestMetadataMaxSize"
         ],
         "properties": {
          "allowInviteNonConnectedUser": {
           "type": "boolean"
          },
          "allowJoinPartyDuringMatchmaking": {
           "type": "boolean"
          },
          "autoKickOnDisconnect": {
           "type": "boolean"
          },
          "autoKickOnDisconnectDelay": {
           "type": "integer",
           "format": "int64"
          },
          "cancelTicketOnDisconnect": {
           "type": "boolean"
          },
          "chatRateLimitBurst": {
           "type": "integer",
           "format": "int32"
          },
          "chatRateLimitDuration": {
           "type": "integer",
           "format": "int64"
          },
          "concurrentUsersLimit": {
           "type": "integer",
           "format": "int32"
          },
          "disableInvitationOnJoinParty": {
           "type": "boolean"
          },
          "enableChat": {
           "type": "boolean"
          },
          "entitlementCheck": {
           "type": "boolean"
          },
          "entitlementItemID": {
           "type": "string"
          },
          "generalRateLimitBurst": {
           "type": "integer",
           "format": "int32"
          },
          "generalRateLimitDuration": {
           "type": "integer",
           "format": "int64"
          },
          "keepPresenceActivityOnDisconnect": {
           "type": "boolean"
          },
          "maxDSWaitTime": {
           "type": "integer",
           "format": "int64"
          },
          "maxFriendsLimit": {
           "type": "integer",
           "format": "int32"
          },
          "maxPartyMember": {
           "type": "integer",
           "format": "int32"
          },
          "namespace": {
           "type": "string"
          },
          "profanityFilter": {
           "type": "boolean"
          },
          "readyConsentTimeout": {
           "type": "integer",
           "format": "int64"
          },
          "requestMetadataMaxSize": {
           "type": "integer",
           "format": "int32"
          },
          "unregisterDelay": {
           "type": "integer",
           "format": "int64"
          }
         }
        })

                401: Unauthorized - ResponseError (Unauthorized)

                403: Forbidden - ResponseError (Forbidden)

                500: Internal Server Error - ResponseError (Internal Server Error)

                ---: HttpResponse (Undocumented Response)

                ---: HttpResponse (Unexpected Content-Type Error)

                ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return content, None
        if code == 401:
            return None, ResponseError.create_from_dict(content)
        if code == 403:
            return None, ResponseError.create_from_dict(content)
        if code == 500:
            return None, ResponseError.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(cls, namespace: str, **kwargs) -> AdminExportConfigV1:
        instance = cls()
        instance.namespace = namespace
        if x_flight_id := kwargs.get("x_flight_id", None):
            instance.x_flight_id = x_flight_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> AdminExportConfigV1:
        instance = cls()
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "namespace": "namespace",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "namespace": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import DtoServiceConfigurationUpdateRequest
from ..models import DtoServicesConfigurationResponse
from ..models import ResponseError

from ..operations.configuration import (
    AdminGetPlatformAccountClosureServicesConfiguration,
)
from ..operations.configuration import AdminGetServicesConfiguration
from ..operations.configuration import (
    AdminResetPlatformAccountClosureServicesConfiguration,
)
from ..operations.configuration import AdminResetServicesConfiguration
from ..operations.configuration import (
    AdminUpdatePlatformAccountClosureServicesConfiguration,
)
from ..operations.configuration import AdminUpdateServicesConfiguration
from ..operations.configuration import DeleteAdminEmailConfiguration
from ..operations.configuration import GetAdminEmailConfiguration
from ..operations.configuration import SaveAdminEmailConfiguration
from ..operations.configuration import UpdateAdminEmailConfiguration


@same_doc_as(AdminGetPlatformAccountClosureServicesConfiguration)
def admin_get_platform_account_closure_services_configuration(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Registered Platform Account Closure Services Configuration (AdminGetPlatformAccountClosureServicesConfiguration)

    Get registered platform account closure services configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/services/platforms/closure/config

        method: GET

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DtoServicesConfigurationResponse (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetPlatformAccountClosureServicesConfiguration.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetPlatformAccountClosureServicesConfiguration)
async def admin_get_platform_account_closure_services_configuration_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Registered Platform Account Closure Services Configuration (AdminGetPlatformAccountClosureServicesConfiguration)

    Get registered platform account closure services configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/services/platforms/closure/config

        method: GET

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DtoServicesConfigurationResponse (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetPlatformAccountClosureServicesConfiguration.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetServicesConfiguration)
def admin_get_services_configuration(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Registered Services Configuration (AdminGetServicesConfiguration)

    Get Registered Services Configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/services/configurations

        method: GET

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DtoServicesConfigurationResponse (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetServicesConfiguration.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetServicesConfiguration)
async def admin_get_services_configuration_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Registered Services Configuration (AdminGetServicesConfiguration)

    Get Registered Services Configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/services/configurations

        method: GET

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DtoServicesConfigurationResponse (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetServicesConfiguration.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminResetPlatformAccountClosureServicesConfiguration)
def admin_reset_platform_account_closure_services_configuration(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Reset Registered Platform Account Closure Services Configuration (AdminResetPlatformAccountClosureServicesConfiguration)

    **[TEST FACILITY ONLY]**
    Reset registered platform account closure services configuration to use the default configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/services/platforms/closure/config

        method: DELETE

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminResetPlatformAccountClosureServicesConfiguration.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminResetPlatformAccountClosureServicesConfiguration)
async def admin_reset_platform_account_closure_services_configuration_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Reset Registered Platform Account Closure Services Configuration (AdminResetPlatformAccountClosureServicesConfiguration)

    **[TEST FACILITY ONLY]**
    Reset registered platform account closure services configuration to use the default configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/services/platforms/closure/config

        method: DELETE

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminResetPlatformAccountClosureServicesConfiguration.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminResetServicesConfiguration)
def admin_reset_services_configuration(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Reset Registered Services Configuration (AdminResetServicesConfiguration)

    **[TEST FACILITY ONLY]**
    Reset Registered Services Configuration to use the default configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/services/configurations/reset

        method: DELETE

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminResetServicesConfiguration.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminResetServicesConfiguration)
async def admin_reset_services_configuration_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Reset Registered Services Configuration (AdminResetServicesConfiguration)

    **[TEST FACILITY ONLY]**
    Reset Registered Services Configuration to use the default configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/services/configurations/reset

        method: DELETE

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminResetServicesConfiguration.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUpdatePlatformAccountClosureServicesConfiguration)
def admin_update_platform_account_closure_services_configuration(
    body: DtoServiceConfigurationUpdateRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Registered Platform Account Closure Services Configuration (AdminUpdatePlatformAccountClosureServicesConfiguration)

    Update registered platform account closure services configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/services/platforms/closure/config

        method: PUT

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED DtoServiceConfigurationUpdateRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DtoServiceConfigurationUpdateRequest (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdatePlatformAccountClosureServicesConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUpdatePlatformAccountClosureServicesConfiguration)
async def admin_update_platform_account_closure_services_configuration_async(
    body: DtoServiceConfigurationUpdateRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Registered Platform Account Closure Services Configuration (AdminUpdatePlatformAccountClosureServicesConfiguration)

    Update registered platform account closure services configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/services/platforms/closure/config

        method: PUT

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED DtoServiceConfigurationUpdateRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DtoServiceConfigurationUpdateRequest (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdatePlatformAccountClosureServicesConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUpdateServicesConfiguration)
def admin_update_services_configuration(
    body: DtoServiceConfigurationUpdateRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Registered Services Configuration (AdminUpdateServicesConfiguration)

    Update Registered Services Configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/services/configurations

        method: PUT

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED DtoServiceConfigurationUpdateRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DtoServiceConfigurationUpdateRequest (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateServicesConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUpdateServicesConfiguration)
async def admin_update_services_configuration_async(
    body: DtoServiceConfigurationUpdateRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Registered Services Configuration (AdminUpdateServicesConfiguration)

    Update Registered Services Configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/services/configurations

        method: PUT

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED DtoServiceConfigurationUpdateRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DtoServiceConfigurationUpdateRequest (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateServicesConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteAdminEmailConfiguration)
def delete_admin_email_configuration(
    emails: List[str],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete admin emails configurations (DeleteAdminEmailConfiguration)

    Delete a list of admin email addresses to stop receiving personal data request notification.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: DELETE

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        emails: (emails) REQUIRED List[str] in query

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteAdminEmailConfiguration.create(
        emails=emails,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteAdminEmailConfiguration)
async def delete_admin_email_configuration_async(
    emails: List[str],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete admin emails configurations (DeleteAdminEmailConfiguration)

    Delete a list of admin email addresses to stop receiving personal data request notification.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: DELETE

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        emails: (emails) REQUIRED List[str] in query

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteAdminEmailConfiguration.create(
        emails=emails,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetAdminEmailConfiguration)
def get_admin_email_configuration(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get admin email addresses configuration (GetAdminEmailConfiguration)

    Get list of admin email address configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: GET

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[str] (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetAdminEmailConfiguration.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetAdminEmailConfiguration)
async def get_admin_email_configuration_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get admin email addresses configuration (GetAdminEmailConfiguration)

    Get list of admin email address configuration.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: GET

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[str] (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetAdminEmailConfiguration.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SaveAdminEmailConfiguration)
def save_admin_email_configuration(
    body: List[str],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Add admin email address configuration (SaveAdminEmailConfiguration)

    Add admin email address for receiving personal data request notification.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: POST

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[str] in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SaveAdminEmailConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SaveAdminEmailConfiguration)
async def save_admin_email_configuration_async(
    body: List[str],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Add admin email address configuration (SaveAdminEmailConfiguration)

    Add admin email address for receiving personal data request notification.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: POST

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[str] in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SaveAdminEmailConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateAdminEmailConfiguration)
def update_admin_email_configuration(
    body: List[str],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update admin email address configuration (UpdateAdminEmailConfiguration)

    Update admin email address for receiving personal data request notification.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: PUT

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[str] in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateAdminEmailConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateAdminEmailConfiguration)
async def update_admin_email_configuration_async(
    body: List[str],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update admin email address configuration (UpdateAdminEmailConfiguration)

    Update admin email address for receiving personal data request notification.
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: PUT

        tags: ["Configuration"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[str] in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateAdminEmailConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



from typing import Optional, Union

import accelbyte_py_sdk.api.iam as iam_service
import accelbyte_py_sdk.services.auth as auth_service
from accelbyte_py_sdk import AccelByteSDK

from ._ctypes import PermissionAction
from ._ctypes import TokenValidationError


class IAMTokenValidator:
    def __init__(
        self,
        sdk: AccelByteSDK,
        token_refresh_interval: Optional[Union[int, float]] = None,
    ) -> None:
        self.sdk = sdk

        if token_refresh_interval is not None:
            auth_service.LoginClientTimer(
                token_refresh_interval,
                repeats=-1,
                autostart=True,
                repeat_on_exception=True,
                sdk=sdk,
            )

    def validate_token(
        self,
        token: str,
        resource: Optional[str] = None,
        action: Optional[PermissionAction] = None,
        namespace: Optional[str] = None,
        user_id: Optional[str] = None,
        **kwargs,
    ) -> Optional[Exception]:
        result, error = iam_service.verify_token_v3(token=token, sdk=self.sdk)
        if error:
            return TokenValidationError(error)

        return None



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Session Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ModelsExtendConfiguration(Model):
    """Models extend configuration (models.ExtendConfiguration)

    Properties:
        app_name: (appName) OPTIONAL str

        custom_url: (customURL) OPTIONAL str

        function_flag: (functionFlag) OPTIONAL int
    """

    # region fields

    app_name: str  # OPTIONAL
    custom_url: str  # OPTIONAL
    function_flag: int  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_app_name(self, value: str) -> ModelsExtendConfiguration:
        self.app_name = value
        return self

    def with_custom_url(self, value: str) -> ModelsExtendConfiguration:
        self.custom_url = value
        return self

    def with_function_flag(self, value: int) -> ModelsExtendConfiguration:
        self.function_flag = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "app_name"):
            result["appName"] = str(self.app_name)
        elif include_empty:
            result["appName"] = ""
        if hasattr(self, "custom_url"):
            result["customURL"] = str(self.custom_url)
        elif include_empty:
            result["customURL"] = ""
        if hasattr(self, "function_flag"):
            result["functionFlag"] = int(self.function_flag)
        elif include_empty:
            result["functionFlag"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        app_name: Optional[str] = None,
        custom_url: Optional[str] = None,
        function_flag: Optional[int] = None,
        **kwargs,
    ) -> ModelsExtendConfiguration:
        instance = cls()
        if app_name is not None:
            instance.app_name = app_name
        if custom_url is not None:
            instance.custom_url = custom_url
        if function_flag is not None:
            instance.function_flag = function_flag
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsExtendConfiguration:
        instance = cls()
        if not dict_:
            return instance
        if "appName" in dict_ and dict_["appName"] is not None:
            instance.app_name = str(dict_["appName"])
        elif include_empty:
            instance.app_name = ""
        if "customURL" in dict_ and dict_["customURL"] is not None:
            instance.custom_url = str(dict_["customURL"])
        elif include_empty:
            instance.custom_url = ""
        if "functionFlag" in dict_ and dict_["functionFlag"] is not None:
            instance.function_flag = int(dict_["functionFlag"])
        elif include_empty:
            instance.function_flag = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsExtendConfiguration]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsExtendConfiguration]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsExtendConfiguration,
        List[ModelsExtendConfiguration],
        Dict[Any, ModelsExtendConfiguration],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "appName": "app_name",
            "customURL": "custom_url",
            "functionFlag": "function_flag",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "appName": False,
            "customURL": False,
            "functionFlag": False,
        }

    # endregion static methods
